diff --git a/source/RobotAPI/components/units/RobotUnit/RobotUnitModules/RobotUnitModuleControlThread.cpp b/source/RobotAPI/components/units/RobotUnit/RobotUnitModules/RobotUnitModuleControlThread.cpp
index b478f9e5b2564b13a2e0e107dfae21fd7145a980..5abecbc624674ca7b139339eb7aef3ab6be58215 100644
--- a/source/RobotAPI/components/units/RobotUnit/RobotUnitModules/RobotUnitModuleControlThread.cpp
+++ b/source/RobotAPI/components/units/RobotUnit/RobotUnitModules/RobotUnitModuleControlThread.cpp
@@ -210,11 +210,11 @@ namespace armarx
 
             rtSwitchControllerSetupChangedControllers = false;
 
             // a missing hearbeat (if required by the config) is interpreted as emergencyStop == true
             if (!emergencyStop && ManagementAttorneyForControlThread::HeartbeatMissing(this))
             {
                 rtSetEmergencyStopState(EmergencyStopState::eEmergencyStopActive);
-                ARMARX_RT_LOGF_ERROR("Emergency Stop was activated because hearbeat is missing!");
+                ARMARX_RT_LOGF_ERROR("Emergency Stop was activated because heartbeat is missing!");
             }
 
             // !emergencyStop && !rtIsInEmergencyStop() -> normal control flow
@@ -210,11 +210,11 @@ namespace armarx
             rtSwitchControllerSetupChangedControllers = false;
 
-            // a missing hearbeat (if required by the config) is interpreted as emergencyStop == true
+            // a missing heartbeat (if required by the config) is interpreted as emergencyStop == true
             if (!emergencyStop && ManagementAttorneyForControlThread::HeartbeatMissing(this))
             {